﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 라인 시리즈
        /// </summary>
        private Line line;

        /// <summary>
        /// 히스토그램 함수
        /// </summary>
        private HistogramFunction histogramFunction;

        /// <summary>
        /// 히스토그램 시리즈
        /// </summary>
        private Histogram histogram;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 라인 시리즈를 생성한다.

            this.line = new Line();

            this.line.Title         = "line";
            this.line.Brush.Color   = Color.FromArgb(255, 0, 0);
            this.line.LinePen.Color = Color.FromArgb(255, 0, 0);

            #endregion
            #region 히스토그램 함수를 생성한다.

            this.histogramFunction = new HistogramFunction();

            this.histogramFunction.Cumulative = false;

            #endregion
            #region 히스토그램을 생성한다.

            this.histogram = new Histogram();

            this.histogram.Title       = "histogram";
            this.histogram.Brush.Color = Color.FromArgb(255, 0, 0);
            this.histogram.DataSource  = this.line;
            this.histogram.Function    = this.histogramFunction;

            #endregion
            #region 티차트 1을 설정한다.

            this.tChart1.Axes.Bottom.Grid.Color = Color.FromArgb(128, 128, 128);
            this.tChart1.Legend.Visible         = false;

            this.tChart1.Series.Add(this.line);

            #endregion
            #region 티차트 2를 설정한다.

            this.tChart2.Axes.Bottom.AxisPen.Visible = false;
            this.tChart2.Axes.Bottom.Grid.Color      = Color.FromArgb(128, 128, 128);
            this.tChart2.Legend.Visible              = false;

            this.tChart2.Series.Add(this.histogram);

            #endregion

            this.line.FillSampleValues(500);

            this.histogram.CheckDataSource();

            this.binCountNumericUpDown.ValueChanged         += binCountNumericUpDown_ValueChanged;
            this.cumulativeHistogramCheckBox.CheckedChanged += cumulativeHistogramCheckBox_CheckedChanged;
            this.refreshButton.Click                        += refreshButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region BIN 수 숫자 UP/DOWN 값 변경시 처리하기 - binCountNumericUpDown_ValueChanged(sender, e)

        /// <summary>
        /// BIN 수 숫자 UP/DOWN 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void binCountNumericUpDown_ValueChanged(object sender, EventArgs e)
        {
            this.histogramFunction.NumBins = (int)this.binCountNumericUpDown.Value;

            this.histogramFunction.Recalculate();
        }

        #endregion
        #region 누적 히스토그램 체크 박스 체크 변경시 처리하기 - cumulativeHistogramCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 누적 히스토그램 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void cumulativeHistogramCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.histogramFunction.Cumulative = this.cumulativeHistogramCheckBox.Checked;

            if(this.histogramFunction.Cumulative)
            {
                this.tChart2.Header.Text = "Cumulative Histogram";
            }
            else
            {
                tChart2.Header.Text = "Histogram";
            }

            this.histogramFunction.Recalculate();
        }

        #endregion
        #region 갱신하기 버튼 클릭시 처리하기 - refreshButton_Click(sender, e)

        /// <summary>
        /// 갱신하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void refreshButton_Click(object sender, EventArgs e)
        {
            this.line.FillSampleValues(500);

            this.histogramFunction.Recalculate();
        }

        #endregion
    }
}